
# 3 levels (B, F, L) B:base words F: First two characters transposed nonwords  L: Last two characters transposed nonwords
# 

#### Libraries needed to run the current R code ####
library(languageR)#version 1.4.1
library(lme4)     #version 1.1-15
library(lattice)  #version 0.20-34
library(lmerTest) # version 2.0-36 #if you want p values for your lmer model 
library(MASS)     #version 7.3-49
library(plyr)     #version 1.8.4
library(yarrr) #version 0.1.5
library(emmeans)
sessionInfo()

#### Part1- Continuous dependent variables of target word analyse####
rm(list=ls()) # Remove any variables
# 1.Load data
# open the csv.file according to data name.

datafile = read.csv(file.choose(), sep = ",", dec = ".")

head(datafile) # generally check the file you have imported
# 2.Set up variables 
colnames(datafile)#checked the column names
col.subject =1   # specify which column your participant number is in
col.Item =2 # specify which column your item number is in
col.Condition =3 # specify which column contains your condition number 
crit = 2.5   # setting the criterium value you want, usually 3 or 2.5 standard deviations

#col.chara_frequency = 4
measure =  "ER" # choose dependent variable
# add to dataframe
datafile$depvar = datafile[,measure]

####Part1-Work out which colums the fixed and random factors are in####
datafile$pp = datafile[,col.subject]
datafile$Item = datafile[,col.Item]
datafile$Condition = datafile[,col.Condition]


#### Part1-Make sure all variables are correct class ####
datafile$depvar = as.numeric(datafile$depvar)

#datafile$Reading_rate = as.factor(datafile$Reading_rate)
datafile$pp = as.factor(datafile$pp)
datafile$Item = as.factor(datafile$Item)
datafile$Condition = factor(datafile$Condition, order=TRUE, levels = c("B","F","L"))


str(datafile)

#### Part1-Remove outlier ####
nrcolumns = ncol(datafile)   # We'll be using this for cleanup later
head(datafile) #let's first have a look
# make a new datafile with fixation durations > 0 ms
between1 = datafile[datafile$depvar > 0, ]
head(between1)
#make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(between1$depvar, list(between1$pp), mean, na.rm = T)
mean.matrix
#make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(between1$depvar, list(between1$pp), sd, na.rm = T)
sd.matrix
#add this data to the actual dataframe
for(i in 1:nrow(between1)){between1$mean.sc[i] = mean.matrix[between1$pp[i]]}
for(i in 1:nrow(between1)){between1$sd.sc[i] = sd.matrix[between1$pp[i]]}
#calculate z-scores
for(i in 1:nrow(between1)) {between1$zscore[i] = (between1$depvar[i] - between1$mean.sc[i])/between1$sd.sc[i]}
# assign a zero value to cells with only 1 observation
between1$zscore[is.na(between1$zscore)] = 0
#make new matrix with only standard deviations below a certain criterium of z-score (in absolute value)
result = between1[abs(between1$zscore) < 3,]#you might want to clean up this data file by removing the added columns
result =  result[,1:nrcolumns]
nrow(datafile)
nrow(datafile)-nrow(result) # calculate how many row you removed
# calculate delete rate
rate=(nrow(datafile)-nrow(result))/nrow(datafile)
rate
datafile <-result
nrow(datafile)# checked the observations after remove outlier

#### Part1-Means,Standard Deviations and Standard Errors####
#### Part1-Data visualization ####
#### Part1-Means,Standard Deviations and Standard Errors####
##### Part1-Means,Standard Deviations and Standard Errors####
###Step1a: make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$Condition), mean, na.rm = T)
mean.matrix
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$Condition), sd, na.rm = T)
sd.matrix
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.sd=apply(mean.matrix,2,sd, na.rm = T)
grand.se=grand.sd/sqrt(39) ##The number of the participants is 39. 
grand.mean
grand.sd
grand.se
# Do we need to transform?
# 1.plot the data
qqnorm(datafile$depvar) # raw data
qqnorm(log(datafile$depvar)) # raw data

# 2.We log transform (log transform data is more linear)
datafile$depvar=log(datafile$depvar)



####Part1-Linear Mixed Models (LMM)####
################ֲʹ#########


# 1.Check the levels of Con
levels(datafile$Condition) 

####TARGET ANALYSES
######contrasts ####################################
contrasts(datafile$Condition) <- contr.sdif(3)
contrasts(datafile$Condition)
################################
#2.Do the contrast.
contrast.matrix <- matrix(c(   
  -1, 0,+1), 3, 1,  # 1 vs 3
  dimnames=list(c("1", "2", "3"), # names of the conditions
                c("1.3"))) # names of the contrasts
# Assign this contrast matrix to wordlength
inv.contrast.matrix <- matrix(t(ginv(contrast.matrix)), 3, 1,
                              dimnames=list(c("1", "2", "3"), 
                                            c("1.3")))
(contrasts(datafile$Con) <- fractions(inv.contrast.matrix))

# NOTE: After run the first contrast,then run lmer models. Then run the second contrast plus the lmer models.
###############################################################################################
# 3.Run linear mixed-effects models (LMM)
##When we ran the models we always began with full models that included the maximum random effects structure.
##But the slopes were removed if the model failed to converge.
# 1. Full model
Adepvar.lmer1 = lmer(depvar ~ Condition+ (1 + Condition|pp) + (1 + Condition|Item), datafile)
summary(Adepvar.lmer1, corr = FALSE)

# 2. Remove correlations for items
Adepvar.lmer2 = lmer(depvar ~ Condition + (1 + Condition|pp) + (0 + Condition|Item), datafile)
summary(Adepvar.lmer2, corr = FALSE)

# 3. Remove interactions (with correlation back in) for items
Adepvar.lmer3 = lmer(depvar ~ Condition + (1 + Condition|pp) + (1|Item), datafile)
summary(Adepvar.lmer3, corr = FALSE)

# 4. Remove correlation and interactions for items
Adepvar.lmer4 = lmer(depvar ~ Condition   + (1 + Condition|Item) + (1|pp), datafile)
summary(Adepvar.lmer4, corr = FALSE)

# 5 Remove one of the slopes
Adepvar.lmer5 = lmer(depvar ~ Condition  + (1|pp) + (1|Item), datafile)
summary(Adepvar.lmer5, corr = FALSE)

Adepvar.glmer5 = glmer(depvar ~ Condition  + (1|pp) + (1|Item),  datafile,family = binomial)
summary(Adepvar.glmer5, corr = FALSE)

# 6 
Adepvar.lmer6 = lmer(depvar ~ Condition  + (1|pp) , datafile)
summary(Adepvar.lmer6, corr = FALSE)


# calculate CI of the model you run.
confint(Adepvar.lmer5, method="Wald") 



